Package: alphaN
Title: Set Alpha Based on Sample Size Using Bayes Factors
Version: 0.2.0
Authors@R: c(
    person("Jesper", "Wulff", , "jwulff@econ.au.dk", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7976-0939")),
    person("Luke", "Taylor", , "lntaylor@econ.au.dk", role = "aut")
  )
Description: Sets the alpha level for coefficients in a regression model
    as a decreasing function of the sample size through the use of
    Jeffreys' Approximate Bayes factor. You tell alphaN() your sample
    size, and it tells you to which value you must lower alpha to avoid
    Lindley's Paradox. For details, see Wulff and Taylor (2024)
    <doi:10.1177/14761270231214429>. Alpha can also be calibrated to the
    effect-size and moment Bayes factors of Klauer, Meyer-Grant, and
    Kellen (2024) <doi:10.3758/s13423-024-02612-2>, which center the
    alternative hypothesis on an effect size of your choosing.
License: MIT + file LICENSE
URL: https://github.com/jespernwulff/alphaN,
        https://jespernwulff.github.io/alphaN/
BugReports: https://github.com/jespernwulff/alphaN/issues
Depends: R (>= 4.0)
Suggests: knitr, rmarkdown, spelling, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-07-11 20:52:38 UTC; au205643
Author: Jesper Wulff [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7976-0939>),
  Luke Taylor [aut]
Maintainer: Jesper Wulff <jwulff@econ.au.dk>
Repository: CRAN
Date/Publication: 2026-07-12 08:40:14 UTC
