# Generated by roxygen2: do not edit by hand

export(JAB)
export(JAB_plot)
export(JABp)
export(JABt)
export(alphaN)
export(alphaN_plot)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,points)
importFrom(stats,dnorm)
importFrom(stats,dt)
importFrom(stats,integrate)
importFrom(stats,nobs)
importFrom(stats,pchisq)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,uniroot)
